summaryrefslogtreecommitdiff
path: root/target_if
diff options
context:
space:
mode:
authorakosigi <akosigi@codeaurora.org>2017-11-03 11:36:32 +0530
committersnandini <snandini@codeaurora.org>2018-02-21 18:20:52 -0800
commit6e19edc1e487ef1f63408b90a6deb48503effc58 (patch)
tree0d0cd6f1f7c525dbede0c78033ba6a5e46f89464 /target_if
parent91f2654d56d26e37fe9fb32272b121add903d1e3 (diff)
downloadqca-wfi-host-cmn-6e19edc1e487ef1f63408b90a6deb48503effc58.tar.gz
qcacmn: Update function name and remove redundant code
Rename scan_tx_ops_register for consistency Remove redundant lines of code in tx_ops registration Change-Id: I3ade89f7eeb1f506f75b5c859dd4bc4242414628 CRs-Fixed: 2127952
Diffstat (limited to 'target_if')
-rw-r--r--target_if/core/src/target_if_main.c5
-rw-r--r--target_if/scan/inc/target_if_scan.h8
-rw-r--r--target_if/scan/src/target_if_scan.c12
3 files changed, 15 insertions, 10 deletions
diff --git a/target_if/core/src/target_if_main.c b/target_if/core/src/target_if_main.c
index 126090536..3a8a924ab 100644
--- a/target_if/core/src/target_if_main.c
+++ b/target_if/core/src/target_if_main.c
@@ -377,7 +377,7 @@ QDF_STATUS target_if_register_umac_tx_ops(struct wlan_lmac_if_tx_ops *tx_ops)
wlan_lmac_if_umac_tx_ops_register(tx_ops);
/* Register scan tx ops */
- target_if_register_scan_tx_ops(&tx_ops->scan);
+ target_if_scan_tx_ops_register(tx_ops);
target_if_atf_tx_ops_register(tx_ops);
@@ -422,9 +422,6 @@ QDF_STATUS target_if_register_tx_ops(struct wlan_lmac_if_tx_ops *tx_ops)
/* Converged UMAC components to register P2P TX-ops */
target_if_p2p_register_tx_ops(tx_ops);
#endif
-#ifdef CONVERGED_TDLS_ENABLE
- target_if_tdls_register_tx_ops(tx_ops);
-#endif
return QDF_STATUS_SUCCESS;
}
diff --git a/target_if/scan/src/target_if_scan.c b/target_if/scan/src/target_if_scan.c
index 665d4f45a..10813f024 100644
--- a/target_if/scan/src/target_if_scan.c
+++ b/target_if/scan/src/target_if_scan.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2017-2018 The Linux Foundation. All rights reserved.
*
* Permission to use, copy, modify, and/or distribute this software for
* any purpose with or without fee is hereby granted, provided that the
@@ -342,8 +342,16 @@ target_if_scan_cancel(struct wlan_objmgr_psoc *psoc,
}
QDF_STATUS
-target_if_register_scan_tx_ops(struct wlan_lmac_if_scan_tx_ops *scan)
+target_if_scan_tx_ops_register(struct wlan_lmac_if_tx_ops *tx_ops)
{
+ struct wlan_lmac_if_scan_tx_ops *scan;
+
+ scan = &tx_ops->scan;
+ if (!scan) {
+ target_if_err("Scan txops NULL");
+ return QDF_STATUS_E_FAILURE;
+ }
+
scan->scan_start = target_if_scan_start;
scan->scan_cancel = target_if_scan_cancel;
scan->pno_start = target_if_pno_start;
diff --git a/target_if/scan/inc/target_if_scan.h b/target_if/scan/inc/target_if_scan.h
index 4662e67a5..62f5186f1 100644
--- a/target_if/scan/inc/target_if_scan.h
+++ b/target_if/scan/inc/target_if_scan.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2017-2018 The Linux Foundation. All rights reserved.
*
* Permission to use, copy, modify, and/or distribute this software for
* any purpose with or without fee is hereby granted, provided that the
@@ -108,15 +108,15 @@ target_if_scan_cancel(struct wlan_objmgr_psoc *psoc,
struct scan_cancel_param *req);
/**
* target_if_register_scan_tx_ops() - lmac handler to register scan tx_ops
* callback functions
- * @scan: wlan_lmac_if_scan_tx_ops object
+ * @tx_ops: wlan_lmac_if_tx_ops object
*
* Return: QDF_STATUS
*/
QDF_STATUS
-target_if_register_scan_tx_ops(struct wlan_lmac_if_scan_tx_ops *scan);
+target_if_scan_tx_ops_register(struct wlan_lmac_if_tx_ops *tx_ops);
/**
* target_if_scan_set_max_active_scans() - lmac handler to set max active scans
@@ -108,15 +108,15 @@ target_if_scan_cancel(struct wlan_objmgr_psoc *psoc,
struct scan_cancel_param *req);
/**
- * target_if_register_scan_tx_ops() - lmac handler to register scan tx_ops
+ * target_if_scan_tx_ops_register() - lmac handler to register scan tx_ops
* callback functions